==> mesian-v0.1.tar.bz2: mesian-v0.1/engine/config.py <==
import sha
import sys, os

sys.path.append("./module")
sys.path.append("./resource")

import Config

# read configuration file, config.cfg
CC = Config.Config("./config.cfg")
Config_CFG = CC.get_all()

#-------------------------------------------------- db
default = {}
default["domain"] = "www.spikeekips.net"
default["interval"] = 10 # second
default["interval_remote_message"] = 300 # second
default["postmaster"] = "spike@www.spikeekips.net" # second

if not Config_CFG["Language"].has_key("encoding") :
	default["encoding"] = "euc-kr"
else :
	default["encoding"] = Config_CFG["Language"]["encoding"]

default["quota"] = {}
default["quota"]["default_quota"] = 50000000 # byte
default["quota"]["over_quota"] = 30 # %

default["item"] = {}
default["item"]["inbox"] = 1
default["item"]["sent"] = 2
default["item"]["tmp"] = 3
default["item"]["trash"] = 4
default["item"]["spam"] = 5

default["item"]["default"] = 3

#---------------------------------------------- send message
if not Config_CFG.has_key("SMTP") :
	raise ValueError, "%s must be set in config file." % "SMTP"

if not "method"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Method"

if not "host"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Host"

if not "port"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Port"

default["send"] = Config_CFG["SMTP"]["method"]

smtp = {}
smtp["server"] = Config_CFG["SMTP"]["host"]
smtp["port"] = Config_CFG["SMTP"]["port"]

#-------------------------------------------------- db
db = {}

if not Config_CFG.has_key("Database") :
	db["host"]			= "localhost"
	#db["port"]			= 3306
	db["unix_socket"]	= "/var/run/mysqld/mysqld.sock"
	db["db"]				= "mesian_devel"
	db["user"]			= "mesian"
	db["passwd"]		= "Ab31a@pa.mesian"
else :
	if not "host"			in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Host"

	if (not "unix_socket" in Config_CFG["Database"].keys()) and \
			(not "port"	in Config_CFG["Database"].keys()) :
		raise ValueError, "%s must be set in config file." % "Unix_socket or Port"

	if not "db"				in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Db"

	if not "user"			in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "User"

	if not "passwd"		in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Passwd"

	db["host"]			= Config_CFG["Database"]["host"]
	db["db"]				= Config_CFG["Database"]["db"]
	db["user"]			= Config_CFG["Database"]["user"]
	db["passwd"]		= Config_CFG["Database"]["passwd"]

	if "unix_socket" in Config_CFG["Database"].keys() :
		db["unix_socket"]	= Config_CFG["Database"]["unix_socket"]
	else :
		db["port"]			= Config_CFG["Database"]["port"]

#-------------------------------------------------- directory
mail_server = {}
mail_server["root"] = Config_CFG["Directory"]["root"]

directory = {}
directory["root"] = Config_CFG["Directory"]["engine"]
directory["log"] = Config_CFG["Directory"]["log"]
directory["pid"] = directory["root"]

www_data = {}
www_data["root"] = Config_CFG["Directory"]["www-data"]

qmail = {}

qmail["directory"] = {}
qmail["file"] = {}

qmail["directory"]["root"] = "%s/server" % mail_server["root"]

qmail["directory"]["bin"] = "%s/bin" % qmail["directory"]["root"]
qmail["directory"]["domains"] = "%s/domains" % mail_server["root"]
qmail["directory"]["message"] = "%s/message" % mail_server["root"]
qmail["directory"]["control"] = "%s/control" % qmail["directory"]["root"]
qmail["directory"]["users"] = "%s/users" % qmail["directory"]["root"]

qmail["file"]["rcpthosts"] = "%s/morercpthosts" % qmail["directory"]["control"]
qmail["file"]["locals"] = "%s/locals" % qmail["directory"]["control"]
qmail["file"]["virtualdomains"] = "%s/virtualdomains" % qmail["directory"]["control"]
qmail["file"]["assign"] = "%s/assign" % qmail["directory"]["users"]
qmail["file"]["qmail-newu"] = "%s/qmail-newu" % qmail["directory"]["bin"]
qmail["file"]["qmail_default"] = "%s/.qmail-default" % qmail["directory"]["domains"]

__author__ =  "Spike^ekipS <spike@spikeekips.net>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "config.py"

==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/engine/config.py <==
import sha
import sys, os

ROOT = sys.path[0]

sys.path.append("%s/module" % ROOT)
sys.path.append("%s/resource" % ROOT)

import Config

# read configuration file, config.cfg
CC = Config.Config("%s/config.cfg" % ROOT)
Config_CFG = CC.get_all()

#-------------------------------------------------- db
default = {}
default["domain"] = "mesian.spikeekips.net"
default["interval"] = 10 # second
default["interval_remote_message"] = 300 # second
default["postmaster"] = "spike@mesian.spikeekips.net" # second

if not Config_CFG["Language"].has_key("encoding") :
	default["encoding"] = "euc-kr"
else :
	default["encoding"] = Config_CFG["Language"]["encoding"]

default["quota"] = {}
default["quota"]["default_quota"] = 50000000 # byte
default["quota"]["over_quota"] = 30 # %

default["item"] = {}
default["item"]["inbox"] = 1
default["item"]["sent"] = 2
default["item"]["tmp"] = 3
default["item"]["trash"] = 4
default["item"]["spam"] = 5

default["item"]["default"] = 3

#---------------------------------------------- send message
if not Config_CFG.has_key("SMTP") :
	raise ValueError, "%s must be set in config file." % "SMTP"

if not "method"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Method"

if not "host"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Host"

if not "port"	in Config_CFG["SMTP"].keys() :
	raise ValueError, "%s must be set in config file." % "Port"

default["send"] = Config_CFG["SMTP"]["method"]

smtp = {}
smtp["server"] = Config_CFG["SMTP"]["host"]
smtp["port"] = Config_CFG["SMTP"]["port"]

#-------------------------------------------------- db
db = {}

if not Config_CFG.has_key("Database") :
	db["host"]			= "localhost"
	#db["port"]			= 3306
	db["unix_socket"]	= "/var/run/mysqld/mysqld.sock"
	db["db"]				= "mesian"
	db["user"]			= "mesianUser"
	db["passwd"]		= "mesianPassword"
else :
	if not "host"			in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Host"

	if (not "unix_socket" in Config_CFG["Database"].keys()) and \
			(not "port"	in Config_CFG["Database"].keys()) :
		raise ValueError, "%s must be set in config file." % "Unix_socket or Port"

	if not "db"				in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Db"

	if not "user"			in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "User"

	if not "passwd"		in Config_CFG["Database"].keys() :
		raise ValueError, "%s must be set in config file." % "Passwd"

	db["host"]			= Config_CFG["Database"]["host"]
	db["db"]				= Config_CFG["Database"]["db"]
	db["user"]			= Config_CFG["Database"]["user"]
	db["passwd"]		= Config_CFG["Database"]["passwd"]

	if "unix_socket" in Config_CFG["Database"].keys() :
		db["unix_socket"]	= Config_CFG["Database"]["unix_socket"]
	else :
		db["port"]			= Config_CFG["Database"]["port"]

#-------------------------------------------------- directory
mail_server = {}
mail_server["root"] = Config_CFG["Directory"]["root"]

directory = {}
directory["root"] = Config_CFG["Directory"]["engine"]
directory["log"] = Config_CFG["Directory"]["log"]
directory["pid"] = directory["root"]

www_data = {}
www_data["root"] = Config_CFG["Directory"]["www-data"]

qmail = {}

qmail["directory"] = {}
qmail["file"] = {}

qmail["directory"]["root"] = "%s/server" % mail_server["root"]

qmail["directory"]["bin"] = "%s/bin" % qmail["directory"]["root"]
qmail["directory"]["domains"] = "%s/domains" % mail_server["root"]
qmail["directory"]["message"] = "%s/message" % mail_server["root"]
qmail["directory"]["control"] = "%s/control" % qmail["directory"]["root"]
qmail["directory"]["users"] = "%s/users" % qmail["directory"]["root"]

qmail["file"]["rcpthosts"] = "%s/morercpthosts" % qmail["directory"]["control"]
qmail["file"]["locals"] = "%s/locals" % qmail["directory"]["control"]
qmail["file"]["virtualdomains"] = "%s/virtualdomains" % qmail["directory"]["control"]
qmail["file"]["assign"] = "%s/assign" % qmail["directory"]["users"]
qmail["file"]["qmail-newu"] = "%s/qmail-newu" % qmail["directory"]["bin"]
qmail["file"]["qmail_default"] = "%s/.qmail-default" % qmail["directory"]["domains"]

__author__ =  "Spike^ekipS <spike@spikeekips.net>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "config.py"


# Mesian is Webmail.
#
# Copyright (C) 2003 Spike^ekipS <spike@spikeekips.net>
#
# Adapted from mesian :
#  Copyright (C) 2003  Spike^ekipS <spike@spikeekips.net>
#
# Contact: mailto:spike@spikeekips.net
# Original site: http://mesian-devel.spikeekips.net/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# Spike^ekipS
#	mailto:spike@spikeekips.net
#
# Original page :
#	http://mesian-devel.spikeekips.net/
#
# Original mesian :
#	Spike^ekipS
#	spike@spikeekips.net
#	Haman Korea
